if(NOT CGAL_CONFIG_INCLUDED)
set(CGAL_CONFIG_INCLUDED 1)

set(CGAL_VERSION 4.9.1)

include(Common)
include(CGALBoost)
include(MPFR)
	
external_project_directories(cgal ${CGAL_VERSION} CGAL_TMP_DIR CGAL_STAMP_DIR CGAL_DOWNLOAD_DIR CGAL_SOURCE_DIR CGAL_BINARY_DIR CGAL_INSTALL_DIR)
append_target_architecture_directory(${CGAL_TMP_DIR} CGAL_TMP_DIR)
append_target_architecture_directory(${CGAL_STAMP_DIR} CGAL_STAMP_DIR)
append_target_architecture_directory(${CGAL_BINARY_DIR} CGAL_BINARY_DIR)
append_target_architecture_directory(${CGAL_INSTALL_DIR} CGAL_INSTALL_DIR)

if(NOT CGAL_ROOT)
	set(CGAL_ROOT ${CGAL_INSTALL_DIR})
endif()

function(cgal_cmake_args RESULT)
    set(CXX_FLAGS "${CXX_ARCH} -Wno-attributes")
	set(${RESULT} 
		-DCMAKE_CXX_COMPILER=${CMAKE_CXX_COMPILER} 
		-DCMAKE_CXX_FLAGS=${CXX_FLAGS}
		-DCMAKE_INSTALL_PREFIX=${CGAL_INSTALL_DIR} 
		-DBOOST_ROOT=${BOOST_ROOT} 
		-DGMP_LIBRARIES=${GMP_LIBRARY}
		-DGMP_INCLUDE_DIR=${GMP_INCLUDE_DIR}
        -DMPFR_LIBRARIES=${MPFR_LIBRARY}
 		-DMPFR_INCLUDE_DIR=${MPFR_INCLUDE_DIR}
		-DWITH_CGAL_Core=on
		-DWITH_CGAL_ImageIO=off
		-DWITH_CGAL_Qt5=off 
		${CGAL_SOURCE_DIR} 
		PARENT_SCOPE)
endfunction()

set(CGAL_EXTERNAL cgal_external)

function(install_cgal)
	message(STATUS "Install CGAL Library ${CGAL_VERSION}")
	
	set(CGAL_URL "https://github.com/CGAL/cgal/releases/download/releases/CGAL-${CGAL_VERSION}/CGAL-${CGAL_VERSION}.zip")
	set(CGAL_MD5 cd2c9be3ad0e44a37c9c0df57bcaf306) 
	
	cgal_cmake_args(CGAL_CMAKE_ARGS)
	
	ExternalProject_Add(${CGAL_EXTERNAL}
		TMP_DIR ${CGAL_TMP_DIR}
		STAMP_DIR ${CGAL_STAMP_DIR}
		DOWNLOAD_DIR ${CGAL_DOWNLOAD_DIR}
		SOURCE_DIR ${CGAL_SOURCE_DIR}
		BINARY_DIR ${CGAL_BINARY_DIR}
		INSTALL_DIR ${CGAL_INSTALL_DIR}
        LOG_INSTALL 1
		
		URL ${CGAL_URL}
		URL_MD5 ${CGAL_MD5}
		CMAKE_ARGS ${CGAL_CMAKE_ARGS}
		BUILD_COMMAND $(MAKE)
		INSTALL_COMMAND $(MAKE) install)
		
	add_dependencies(${CGAL_EXTERNAL} ${MPFR_EXTERNAL} ${CGAL_BOOST_EXTERNAL})
endfunction()

macro(require_cgal)
    require_cgal_boost()
    require_mpfr()
    find_package(CGAL REQUIRED)
	include_directories(${CGAL_INCLUDE_DIR})
	link_directories(${CGAL_LIBRARY_DIR})
endmacro()

macro(find_cgal)
    find_cgal_boost()
    if(MINGW)
        find_mpfr()
    else()
        require_mpfr()
    endif()            
    find_package(CGAL)
    if(NOT CGAL_FOUND)
    	install_cgal()
	  	include_directories(${CGAL_INSTALL_DIR}/include)
		link_directories(${CGAL_INSTALL_DIR}/lib)
		if(MINGW)
		    set(CGAL_RUNTIME_DIR ${CGAL_INSTALL_DIR}/bin)
		else()
		    set(CGAL_RUNTIME_DIR ${CGAL_INSTALL_DIR}/lib)
		endif()
    else()
	  	include_directories(${CGAL_INCLUDE_DIR})
		link_directories(${CGAL_LIBRARY_DIR})
    endif()
endmacro()
	
remove_directory_command(REMOVE_DIRECTORY_COMMAND)

add_custom_target(clean_cgal
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${CGAL_SOURCE_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${CGAL_BINARY_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${CGAL_INSTALL_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${CGAL_TMP_DIR}
   COMMAND ${REMOVE_DIRECTORY_COMMAND} ${CGAL_STAMP_DIR})	

endif()
   