/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/jni/process/zoning/zoning_process.hpp>
#include <geofis/jni/process/zoning/zoning_process_impl.hpp>
#include <geofis/jni/feature/feature_range.hpp>

using namespace boost::adaptors;

namespace geofis {

zoning_process::zoning_process(JNIEnv *jenv, jobject object) : impl(new zoning_process_impl(jni::make_feature_range<zoning_process_traits::feature_type>(jenv, object))) {}

zoning_process::~zoning_process() {}

void zoning_process::set_border(const polygon_type &border) {
	impl->set_border(border);
}

void zoning_process::compute_voronoi_process() {
	impl->compute_voronoi_process();
}

void zoning_process::release_voronoi_process() {
	impl->release_voronoi_process();
}

const zoning_process::voronoi_map_type &zoning_process::get_voronoi_map() const {
	return impl->get_voronoi_map();
}

void zoning_process::set_neighborhood(const neighborhood_type &neighborhood) {
	impl->set_neighborhood(neighborhood);
}

void zoning_process::compute_neighborhood_process() {
	impl->compute_neighborhood_process();
}

void zoning_process::release_neighborhood_process() {
	impl->release_neighborhood_process();
}

zoning_process::const_zone_neighbor_range_type zoning_process::get_zone_neighbors() const {
	return impl->get_zone_neighbors();
}

zoning_process::const_zone_neighbor_range_type zoning_process::get_filtered_zone_neighbors() const {
	return impl->get_filtered_zone_neighbors();
}

void zoning_process::set_aggregation(const aggregation_type &aggregation) {
	impl->set_aggregation(aggregation);
}

void zoning_process::set_zone_distance(const zone_distance_type &zone_distance) {
	impl->set_zone_distance(zone_distance);
}

void zoning_process::set_multidimensional_distance(const multidimensional_distance_type &multidimensional_distance) {
	impl->set_multidimensional_distance(multidimensional_distance);
}

void zoning_process::set_attribute_distances(JNIEnv *jenv, jobject attribute_distances) {
	impl->set_attribute_distances(jenv, attribute_distances);
}

void zoning_process::compute_fusion_process() {
	impl->compute_fusion_process();
}

void zoning_process::release_fusion_process() {
	impl->release_fusion_process();
}

size_t zoning_process::get_fusion_size() const {
	return impl->get_fusion_size();
}

zoning_process::fusion_map_range_type zoning_process::get_fusion_maps(size_t begin, size_t end, bool compute_zones) {
	return impl->get_fusion_maps(begin, end, compute_zones);
}

zoning_process::reverse_fusion_map_range_type zoning_process::get_reverse_fusion_maps(size_t begin, size_t end, bool compute_zones) {
	return reverse(impl->get_fusion_maps(begin, end, compute_zones));
}

size_t zoning_process::get_unique_feature_size() const {
	return impl->get_unique_feature_size();
}

size_t zoning_process::get_bounded_feature_size() const {
	return impl->get_bounded_feature_size();
}

void zoning_process::set_merge(const optional_merge_type &optional_merge) {
	impl->set_merge(optional_merge);
}

zoning_process::post_process_type *zoning_process::get_new_post_process(const fusion_map_type &fusion_map) {
	return impl->get_new_post_process(fusion_map);
}

zoning_process::post_process_type &zoning_process::get_post_process(const fusion_map_type &fusion_map) {
	return impl->get_post_process(fusion_map);
}

void zoning_process::compute_post_process(post_process_type &post_process) {
	impl->compute_post_process(post_process);
}

void zoning_process::release_post_process() {
	impl->release_post_process();
}

} // namespace geofis
