/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/fusion/distance/variant_feature_distance.hpp>
#include <geofis/data/feature.hpp>
#include <geofis/algorithm/zoning/fusion/distance/variant_multidimensional_distance.hpp>
#include <geofis/algorithm/zoning/fusion/distance/variant_attribute_distance.hpp>
#include <boost/function.hpp>
#include <boost/assign/list_of.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <adobe/timer.hpp>

using namespace util;
using namespace geofis;
using namespace adobe;
using namespace boost::assign;

#define DELTA 0.1
#define FEATURE_DISTANCE_COUNT 10000000

struct geometry_type {};

typedef feature<int, geometry_type, double> monodimensional_feature_type;
typedef std::vector<double> attribute_range_type;
typedef feature<int, geometry_type, attribute_range_type> multidimensional_feature_type;
typedef boost::function<double (double lhs, double rhs)> attribute_distance_function_type;

typedef feature_distance<euclidean_distance<double>, euclidean_distance<double> > 			feature_distance_euclidean_euclidean_type;
typedef feature_distance<euclidean_distance<double>, attribute_distance_function_type> 	    feature_distance_euclidean_function_type;
typedef feature_distance<euclidean_distance<double>, void> 									feature_distance_euclidean_void_type;
typedef feature_distance<void, euclidean_distance<double> > 								feature_distance_void_euclidean_type;
typedef feature_distance<void, variant_attribute_distance> 									feature_distance_void_variant_type;
typedef feature_distance<variant_multidimensional_distance, euclidean_distance<double> > 	feature_distance_variant_euclidean_type;
typedef feature_distance<variant_multidimensional_distance, variant_attribute_distance> 	feature_distance_variant_variant_type;

//typedef typename variant_feature_distance_traits<variant_multidimensional_distance, variant_attribute_distance>::variant_feature_distance_type variant_feature_distance_type;
typedef typename variant_feature_distance_traits<variant_multidimensional_distance, variant_attribute_distance>::variant_feature_distance_type variant_feature_distance_type;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class feature_distance_timing_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( feature_distance_timing_tester );

	CPPUNIT_TEST( test_euclidean_euclidean );
	CPPUNIT_TEST( test_euclidean_function );
	CPPUNIT_TEST( test_euclidean_void );
	CPPUNIT_TEST( test_void_euclidean );
	CPPUNIT_TEST( test_void_euclidean_mono );
	CPPUNIT_TEST( test_void_variant );
	CPPUNIT_TEST( test_variant_euclidean );
	CPPUNIT_TEST( test_variant_variant );
	CPPUNIT_TEST( test_variant_feature_distance );

	CPPUNIT_TEST_SUITE_END();

public:

	void test_euclidean_euclidean() {
		feature_distance_euclidean_euclidean_type feature_distance(1);
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<euclidean_distance<double>, euclidean_distance<double> >");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	void test_euclidean_function() {
		attribute_distance_function_type attribute_function = euclidean_distance<double>();
		feature_distance_euclidean_function_type feature_distance(1, attribute_function);
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<euclidean_distance<double>, attribute_distance_function_type>");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	void test_euclidean_void() {
		feature_distance_euclidean_void_type feature_distance;
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<euclidean_distance<double>, void>");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	void test_void_euclidean() {
		feature_distance_void_euclidean_type feature_distance;
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<void, euclidean_distance<double> >");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	// l'execution avec variant_attribute_distance contenant fispro::fuzzy_distance est un peu plus longue
	// la fonction binaire FISIN::Distance n'est pas inlin� dans ce cas
	void test_void_variant() {
		feature_distance_void_variant_type feature_distance;
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<void, variant_attribute_distance>");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	void test_void_euclidean_mono() {
		feature_distance_void_euclidean_type feature_distance;
		double distance = 0;
		monodimensional_feature_type f1(0, geometry_type(), 0.1);
		monodimensional_feature_type f2(0, geometry_type(), 0.2);
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<void, euclidean_distance<double> > mono");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	void test_variant_euclidean() {
		feature_distance_variant_euclidean_type feature_distance(1);
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<variant_multidimensional_distance, euclidean_distance<double> >");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	// l'execution avec variant_attribute_distance contenant fispro::fuzzy_distance est un peu plus longue
	// la fonction binaire FISIN::Distance n'est pas inlin� dans ce cas
	void test_variant_variant() {
		feature_distance_variant_variant_type feature_distance(1);
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("feature_distance<variant_multidimensional_distance, variant_attribute_distance>");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}

	void test_variant_feature_distance() {
		util::binary_adaptor<variant_feature_distance_type> feature_distance(make_multidimensional_feature_distance<variant_attribute_distance>(variant_multidimensional_distance(), list_of(variant_attribute_distance())));
		//util::binary_adaptor<variant_feature_distance_type> feature_distance(make_multidimensional_feature_distance<variant_attribute_distance>(variant_multidimensional_distance(), list_of(variant_attribute_distance())));
		//util::binary_adaptor<variant_feature_distance_type> feature_distance(make_monodimensional_feature_distance<variant_attribute_distance>(variant_attribute_distance()));
		multidimensional_feature_type f1(0, geometry_type(), list_of(0.1));
		multidimensional_feature_type f2(0, geometry_type(), list_of(0.2));
		double distance = 0;
		timer_t timer;
		for(long count=0 ; count < FEATURE_DISTANCE_COUNT ; count++)
			distance += feature_distance(f1, f2);
		timer.report("variant_feature_distance<variant_multidimensional_distance, variant_attribute_distance>");
		CPPUNIT_ASSERT_DOUBLES_EQUAL(FEATURE_DISTANCE_COUNT * 0.1, distance, DELTA);
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( feature_distance_timing_tester );
