/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/fusion/fusion_zone_range.hpp>
#include <boost/ref.hpp>
#include <boost/utility.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/range/sub_range.hpp>
#include <boost/range/algorithm/for_each.hpp>
#include <boost/type_traits/remove_const.hpp>
#include <pstade/oven/taken.hpp>
#include <util/address_equal.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <vector>
#include <list>

#include <pstade/oven/jointed.hpp>

using namespace std;
using namespace geofis;
using namespace boost;
using namespace boost::assign;

struct zone {

	friend bool operator==(const zone &lhs, const zone &rhs) {
		return util::address_equal(lhs, rhs);
	}
};

struct zone_fusion {

	typedef zone zone_type;
	typedef typename boost::reference_wrapper<const zone> zone_reference;

	zone_fusion(const zone &zone1, const zone &zone2) : zone1(zone1), zone2(zone2) {}

	zone &get_fusion() { return fusion; }
	const zone &get_fusion() const { return fusion; }

	bool contain_zone(const zone &zone) const {
		return util::address_equal(zone, unwrap_ref(zone1)) || util::address_equal(zone, unwrap_ref(zone2));
	}

	zone_reference zone1;
	zone_reference zone2;
	zone fusion;
};

typedef vector<zone> zone_container_type;
typedef list<zone_fusion> fusion_container_type;
typedef sub_range<zone_container_type> zone_range_type;
typedef sub_range<const zone_container_type> const_zone_range_type;
typedef sub_range<fusion_container_type> fusion_range_type;
typedef sub_range<const fusion_container_type> const_fusion_range_type;
//typedef typename fusion_zone_range_traits<zone_container_type, fusion_container_type>::base_type fusion_zone_range_type;
//typedef typename pstade::oven::taken_traits<fusion_container_type>::result_type taken_range_type;

template <class FusionRange> const zone &fusion(const FusionRange &fusion_range, int index) {
	return next(begin(fusion_range), index)->get_fusion();
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class fusion_zone_range_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( fusion_zone_range_tester );

	CPPUNIT_TEST( test );

	CPPUNIT_TEST_SUITE_END();

public:

	template <class FusionZoneRange> void test_step1(const FusionZoneRange &fusion_zone_range, const zone_container_type &zones, const fusion_container_type &fusions) {
		CPPUNIT_ASSERT_EQUAL( 9, distance(fusion_zone_range) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[3]))(cref(zones[4]))(cref(zones[5]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 0))), fusion_zone_range );
	}

	template <class FusionZoneRange> void test_step2(const FusionZoneRange &fusion_zone_range, const zone_container_type &zones, const fusion_container_type &fusions) {
		CPPUNIT_ASSERT_EQUAL( 8, distance(fusion_zone_range) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[5]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 0)))(cref(::fusion(fusions, 1))), fusion_zone_range );
	}

	template <class FusionZoneRange> void test_step3(const FusionZoneRange &fusion_zone_range, const zone_container_type &zones, const fusion_container_type &fusions) {
		CPPUNIT_ASSERT_EQUAL( 7, distance(fusion_zone_range) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 0)))(cref(::fusion(fusions, 2))), fusion_zone_range );
	}

	template <class FusionZoneRange> void test_step4(const FusionZoneRange &fusion_zone_range, const zone_container_type &zones, const fusion_container_type &fusions) {
		CPPUNIT_ASSERT_EQUAL( 6, distance(fusion_zone_range) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[2]))(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 3))), fusion_zone_range );
	}

	template <class FusionZoneRange> void test_step5(const FusionZoneRange &fusion_zone_range, const zone_container_type &zones, const fusion_container_type &fusions) {
		CPPUNIT_ASSERT_EQUAL( 5, distance(fusion_zone_range) );
		CPPUNIT_ASSERT_RANGES_EQUAL( list_of(cref(zones[6]))(cref(zones[7]))(cref(zones[8]))(cref(zones[9]))(cref(::fusion(fusions, 4))), fusion_zone_range );
	}

	struct no_const_zone_tester {

		template <class Zone> void operator()(Zone &zone) const {
			CPPUNIT_ASSERT( !is_const<Zone>::value );
		}
	};

	template <class FusionZoneRange> void test_no_const_fusion_zone_range(const FusionZoneRange &fusion_zone_range) {
		boost::for_each(fusion_zone_range, no_const_zone_tester());
	}

	struct const_zone_tester {

		template <class Zone> void operator()(Zone &zone) const {
			CPPUNIT_ASSERT( is_const<Zone>::value );
		}
	};

	template <class FusionZoneRange> void test_const_fusion_zone_range(const FusionZoneRange &fusion_zone_range) {
		boost::for_each(fusion_zone_range, const_zone_tester());
	}

	template <class FusionZoneRange> void test_compile_error_const_fusion_zone_range(const FusionZoneRange &fusion_zone_range) {
		boost::for_each(fusion_zone_range, no_const_zone_tester());
	}

	void test() {

		try {

			zone_container_type zones = list_of(zone())(zone())(zone())(zone())(zone())(zone())(zone())(zone())(zone())(zone());
			fusion_container_type fusions;

			fusions.push_back(zone_fusion(zones[0], zones[1]));
			test_step1(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(fusions)), zones, fusions);

			fusions.push_back(zone_fusion(zones[3], zones[4]));
			test_step2(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(fusions)), zones, fusions);
			test_step1(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 1)), zones, fusions);

			fusions.push_back(zone_fusion(::fusion(fusions, 1), zones[5]));
			test_step3(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(fusions)), zones, fusions);
			test_step2(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 2)), zones, fusions);
			test_step1(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 1)), zones, fusions);

			fusions.push_back(zone_fusion(::fusion(fusions, 0), ::fusion(fusions, 2)));
			test_step4(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(fusions)), zones, fusions);
			test_step3(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 3)), zones, fusions);
			test_step2(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 2)), zones, fusions);
			test_step1(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 1)), zones, fusions);

			fusions.push_back(zone_fusion(zones[2], ::fusion(fusions, 3)));
			test_step5(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(fusions)), zones, fusions);
			test_step4(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 4)), zones, fusions);
			test_step3(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 3)), zones, fusions);
			test_step2(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 2)), zones, fusions);
			test_step1(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, 1)), zones, fusions);

			//fusion_zone_range_type no_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(fusions)));
			//test_no_const_fusion_zone_range(no_const_fusion_zone_range);
			zone_range_type zone_range = make_iterator_range(zones);
			fusion_range_type fusion_range = make_iterator_range(fusions);
			std::cout << "----------" << endl;
			test_no_const_fusion_zone_range(make_fusion_zone_range(zones, fusions));
			test_no_const_fusion_zone_range(make_fusion_zone_range(zones, fusion_range));
			test_no_const_fusion_zone_range(make_fusion_zone_range(zone_range, fusions));
			test_no_const_fusion_zone_range(make_fusion_zone_range(zone_range, fusion_range));
			test_no_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(zones), fusion_range));
			test_no_const_fusion_zone_range(make_fusion_zone_range(zone_range, make_iterator_range(fusions)));
			test_no_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(fusions)));
			//taken_range_type taken_range(pstade::oven::make_taken(fusions, 4));
			test_no_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(zones), pstade::oven::make_taken(fusions, fusions.size())));
			std::cout << "----------" << endl;

			const zone_container_type const_zones = zones;
			const fusion_container_type const_fusions = fusions;
			//test_const_fusion_zone_range(make_fusion_zone_range(zones, fusions));
			test_const_fusion_zone_range(make_fusion_zone_range(const_zones, fusions));
			//test_const_fusion_zone_range(make_fusion_zone_range(zones, const_fusions));
			test_const_fusion_zone_range(make_fusion_zone_range(const_zones, const_fusions));
			test_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(const_zones), make_iterator_range(fusions)));
			//test_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(const_fusions)));
			test_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(const_zones), make_iterator_range(const_fusions)));
			//test_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(zones), make_iterator_range(const_fusions)));
			test_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(const_zones), pstade::oven::make_taken(const_fusions, const_fusions.size())));
			// uncomment the following line causes a compile error
			//test_compile_error_const_fusion_zone_range(make_fusion_zone_range(make_iterator_range(const_zones), pstade::oven::make_taken(fusions, fusions.size())));

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( fusion_zone_range_tester );
