/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/zoning.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <CGAL/Exact_predicates_exact_constructions_kernel.h>
#include <CGAL/Point_2.h>
#include <CGAL/Polygon_2.h>
#include <CGAL/Polygon_with_holes_2.h>
#include <CGAL/Polygon_2_algorithms.h>
#include <boost/assign/list_of.hpp>
#include <geofis/geometry/polygon.hpp>

using namespace geofis;
using namespace CGAL;
using namespace boost;
using namespace boost::assign;

typedef Exact_predicates_exact_constructions_kernel kernel_type;
typedef CGAL::Point_2<kernel_type> point_type;
typedef CGAL::Polygon_2<kernel_type> polygon_type;
typedef CGAL::Polygon_with_holes_2<kernel_type> polygon_with_holes_type;

typedef feature<std::string, point_type, std::vector<double> > feature_type;
typedef zoning<kernel_type, feature_type> zoning_type;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class zoning_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( zoning_tester );

	CPPUNIT_TEST( test );

	CPPUNIT_TEST_SUITE_END();

public:

	struct test_is_on_boundary {

		test_is_on_boundary(const polygon_type &expected) : expected(expected) {}

		void operator()(const point_type &point) {
			//if(bounded_side_2(expected.vertices_begin(), expected.vertices_end(), point, kernel_type()) != ON_BOUNDARY)
			//	std::cout << "test_is_on_boundary " << point << std::endl;
			CPPUNIT_ASSERT_EQUAL( ON_BOUNDARY, bounded_side_2(expected.vertices_begin(), expected.vertices_end(), point, kernel_type()) );
		}

		const polygon_type &expected;
	};

	void test_last_polygon(const polygon_type &expected, const polygon_type &last_polygon) {
		std::for_each(last_polygon.vertices_begin(), last_polygon.vertices_end(), test_is_on_boundary(expected));
		std::for_each(expected.vertices_begin(), expected.vertices_end(), test_is_on_boundary(last_polygon));
	}


	void test_last_polygon(const polygon_type &expected, const polygon_with_holes_type &last_polygon) {
		CPPUNIT_ASSERT( !last_polygon.has_holes() );
		CPPUNIT_ASSERT( !last_polygon.outer_boundary().is_empty() );
		test_last_polygon(expected, last_polygon.outer_boundary());
	}

	void test() {

		try {

			std::vector<feature_type> features = list_of(feature_type("01", point_type(763801.18, 194121.76), list_of(3.505)))(feature_type("02", point_type(763819.98, 194115.71), list_of(2.469)))(feature_type("03", point_type(763838.94, 194109.64), list_of(2.242)))(feature_type("04", point_type(763819.6, 194094.93), list_of(0.683)))(feature_type("05", point_type(763838.37, 194088.79), list_of(1.81)))(feature_type("06", point_type(763776.36, 194103.68), list_of(2.645)))(feature_type("07", point_type(763801.94, 194095.32), list_of(2.888)))(feature_type("08", point_type(763766.53, 194096.45), list_of(2.097)))(feature_type("09", point_type(763785.86, 194084.9), list_of(3.476)))(feature_type("10", point_type(763811.39, 194076.6), list_of(1.754)))(feature_type("11", point_type(763824.23, 194064.06), list_of(2.8)))(feature_type("12", point_type(763755.44, 194068.47), list_of(2.091)))(feature_type("13", point_type(763789.42, 194057.37), list_of(2.356)))(feature_type("14", point_type(763816.55, 194045.93), list_of(1.146)))(feature_type("15", point_type(763759.69, 194059.17), list_of(1.09)))(feature_type("16", point_type(763772.92, 194054.9), list_of(1.129)))(feature_type("17", point_type(763820.63, 194039.45), list_of(0.989)))(feature_type("18", point_type(763768.57, 194040.58), list_of(1.124)))(feature_type("19", point_type(763781.82, 194036.17), list_of(0.418)))(feature_type("20", point_type(763796.03, 194031.6), list_of(1.194)))(feature_type("21", point_type(763738.55, 194045.17), list_of(1.623)))(feature_type("22", point_type(763755.6, 194033.91), list_of(1.563)))(feature_type("23", point_type(763795.45, 194020.93), list_of(0.694)))(feature_type("24", point_type(763817.38, 194013.83), list_of(0.58)))(feature_type("25", point_type(763800.4, 194013.94), list_of(1.033)))(feature_type("26", point_type(763729.74, 194031.98), list_of(1.909)))(feature_type("27", point_type(763770.87, 194013.28), list_of(1.752)))(feature_type("28", point_type(763728.54, 194021.66), list_of(2.502)))(feature_type("29", point_type(763775.44, 194001.26), list_of(0.805)))(feature_type("30", point_type(763805.68, 193991.36), list_of(2.126)));
			polygon_type boundary = make_polygon<kernel_type>(list_of(point_type(763775.440, 194001.260))(point_type(763728.540, 194021.660))(point_type(763729.740, 194031.980))(point_type(763766.530, 194096.450))(point_type(763776.360, 194103.680))(point_type(763801.180, 194121.760))(point_type(763838.940, 194109.640))(point_type(763838.370, 194088.790))(point_type(763817.380, 194013.830))(point_type(763805.680, 193991.360)));

			zoning_type zoning;
			zoning.set_features(features, boundary);
			zoning.start();
			CPPUNIT_ASSERT_EQUAL( features.size() - 1, zoning.fusion_size() );
			test_last_polygon(boundary, zoning.get_last_geometry());

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( zoning_tester );

