/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/algorithm/zoning/triangulation/edge_to_zone_pair.hpp>
#include <geofis/data/feature.hpp>
#include <geofis/data/geometry_iterator.hpp>
#include <geofis/algorithm/zoning/zone.hpp>
#include <geofis/algorithm/zoning/triangulation/delaunay_traits.hpp>
#include <geofis/algorithm/zoning/find_zone_pair_id.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <CGAL/Exact_predicates_exact_constructions_kernel.h>
#include <CGAL/Polygon_2.h>
#include <boost/utility.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/iterator/transform_iterator.hpp>
#include <boost/range/algorithm_ext.hpp>
#include <pstade/oven/exists.hpp>

using namespace std;
using namespace geofis;
using namespace CGAL;
using namespace boost;
using namespace boost::assign;
using namespace pstade::oven;

typedef Exact_predicates_exact_constructions_kernel kernel_type;
typedef Point_2<kernel_type> point_type;
typedef Polygon_2<kernel_type> polygon_type;

typedef feature<char, point_type, vector<double> > feature_type;
typedef vector<feature_type> vector_feature_type;

typedef geofis::zone<polygon_type, feature_type> zone_type;
typedef vector<zone_type> vector_zone_type;

typedef zone_pair<zone_type> zone_pair_type;
typedef vector<zone_pair_type> vector_zone_pair_type;

typedef typename delaunay_traits<kernel_type, const zone_type *>::delaunay_triangulation_type delaunay_triangulation_type;

struct zone_pair_distance {

	typedef double result_type;

	template <class Zone> double operator()(const Zone &lhs, const Zone &rhs) const {
		return 0;
	}
};

typedef edge_to_zone_pair<zone_type, zone_pair_distance> edge_to_zone_pair_type;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class edge_to_zone_pair_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( edge_to_zone_pair_tester );

	CPPUNIT_TEST( test );

	CPPUNIT_TEST_SUITE_END();

public:

	void test() {

		try {

			feature_type feature1('a', point_type(1, 1), list_of(0.1)(0.2));
			feature_type feature2('b', point_type(5, 1), list_of(0.2)(0.3));
			feature_type feature3('c', point_type(5, 5), list_of(0.3)(0.4));
			feature_type feature4('d', point_type(1, 5), list_of(0.4)(0.5));
			feature_type feature5('e', point_type(3, 3), list_of(0.5)(0.6));
			vector_feature_type features = list_of(feature1)(feature2)(feature3)(feature4)(feature5);

			vector_zone_type zones(make_transform_iterator(features.begin(), make_zone<polygon_type, feature_type>()), make_transform_iterator(features.end(), make_zone<polygon_type, feature_type>()));

			delaunay_triangulation_type delaunay;
			delaunay.insert(make_zip_iterator(make_tuple(make_geometry_iterator(features.begin()), make_transform_iterator(zones.begin(), &addressof<const zone_type>))), make_zip_iterator(make_tuple(make_geometry_iterator(features.end()), make_transform_iterator(zones.end(), &addressof<const zone_type>))));

			vector_zone_pair_type zone_pairs(make_transform_iterator(delaunay.finite_edges_begin(), edge_to_zone_pair_type()), make_transform_iterator(delaunay.finite_edges_end(), edge_to_zone_pair_type()));
			CPPUNIT_ASSERT_EQUAL( (size_t)8, zone_pairs.size() );

			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('a', 'b')) );
			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('b', 'c')) );
			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('c', 'd')) );
			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('d', 'a')) );
			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('e', 'a')) );
			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('e', 'b')) );
			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('e', 'c')) );
			CPPUNIT_ASSERT( exists(zone_pairs, zone_pair_id_finder('e', 'd')) );

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}
};

CPPUNIT_TEST_SUITE_REGISTRATION( edge_to_zone_pair_tester );

