/**
 * GeoFIS Native Library
 *
 * Copyright (C) 2013 IRSTEA INRA SupAgro
 *
 * IDDN.FR.001.390016.000.R.P.2013.000.31235
 *
 * Auteurs/Authors:
 *     Jean-luc Lablée - IRSTEA
 *     Serge Guillaume - IRSTEA
 *     Brigitte Charnomordic - INRA
 *     Anne Tireau - INRA
 *     Bruno Tisseyre - SupAgro
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL license and that you accept its terms.
 */
#include <geofis/data/geometry_iterator.hpp>
#include <geofis/data/dataset.hpp>
#include <geofis/geometry/point_2_maker.hpp>
#include <util/data/coupling_loader.hpp>
#include <cppunit/extensions/HelperMacros.h>
#include <cppunit/specializations.hpp>
#include <CGAL/Cartesian.h>
#include <boost/mpl/vector.hpp>
#include <boost/range/counting_range.hpp>
#include <boost/assign/list_of.hpp>
#include <boost/range/algorithm_ext.hpp>

#include <util/type.hpp>

using namespace geofis;
using namespace CGAL;
using namespace boost;
using namespace boost::assign;

typedef Cartesian<double> kernel_type;
typedef Point_2<kernel_type> geometry_type;
typedef dataset<geometry_type> dataset_type;
typedef dataset<geometry_type, double> dataset_double_type;

typedef feature<size_t, geometry_type, std::vector<double> > mutable_feature;
typedef std::vector<mutable_feature> vector_mutable_feature;

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

class geometry_iterator_tester : public CppUnit::TestFixture {

	CPPUNIT_TEST_SUITE( geometry_iterator_tester );

	CPPUNIT_TEST( test );
	//CPPUNIT_TEST( test_sequence );

	CPPUNIT_TEST_SUITE_END();

public:

	/*struct feature_visitor : public boost::static_visitor<void> {

		void operator() (int32_t value) { attributes.push_back(value); }
		template <class T> void operator() (const T &) {}
		void operator() (const geometry_type &geometry) { this->geometry = geometry; }

		geometry_type geometry;
		std::vector<int32_t> attributes;
	};

	template <class Feature> static void test_feature_visitation(const Feature &feature, size_t index) {
		feature_visitor visitor;
		apply_feature_attribute_visitor(visitor, feature);
		CPPUNIT_ASSERT_EQUAL( geometry_type(index + 1, index + 2), visitor.geometry );
		CPPUNIT_ASSERT_RANGES_EQUAL( counting_range((int32_t)index + 3, (int32_t)index + 5), make_iterator_range(visitor.attributes) );
	}

	struct test_feature {

		template <class Feature> void operator() (const Feature &feature, size_t index) const {
			CPPUNIT_ASSERT_EQUAL( index, feature.get_id() );
			CPPUNIT_ASSERT_EQUAL( geometry_type(index + 1, index + 2), feature.get_geometry() );
			CPPUNIT_ASSERT_EQUAL( 2, distance(feature.get_attribute_range()) );
			CPPUNIT_ASSERT_RANGES_EQUAL( counting_range((int32_t)index + 3, (int32_t)index + 5), feature.get_attribute_range() );
			//std::cout << util::make_type(*boost::begin(feature.get_attribute_range())).name() << std::endl;
			test_feature_visitation(feature, index);
		}
	};
*/
	struct print_attribute {

		template <class Feature> void operator()(const Feature &feature) {
			std::cout << *boost::begin(feature.get_attribute_range()) << std::endl;
		}
	};

	/*template <class AttributeRange> void test_attributes(const AttributeRange &attribute_range) {
		boost::for_each(attribute_range, print_attribute());
	}*/

	template <class FeatureRange> void test_geometries(const FeatureRange &feature_range) {
		//std::cout << util::Type<FeatureRange>::name() << std::endl;
		//test_geometries(make_geometry_iterator(boost::begin(feature_range)), make_geometry_iterator(boost::end(feature_range)));
		//CPPUNIT_ASSERT_EQUAL( 4, distance(feature_range) );
		//for_each(feature_range, counting_range(0, 4), test_feature());
		/*for_each(feature_range, print_attribute());
		attribute_range<FeatureRange> attributes(feature_range);
		util::normalize(attributes);
		for_each(feature_range, print_attribute());*/
		//geofis::attribute_range<FeatureRange> attribute_range(feature_range);
	}


	void test() {

		try {

			dataset_double_type dataset(util::make_coupling_loader(counting_range(1.0, 6.0), counting_range(2.0, 7.0), point_2_maker<kernel_type>()), list_of(counting_range(3.0, 8.0))(counting_range(4.0, 9.0)));
			test_geometries(dataset.get_feature_range());
			//*begin(dataset.get_feature_range());
			//mutable_feature feature(*begin(dataset.get_feature_range()));
			/*vector_mutable_feature features;
			push_back(features).range(dataset.get_feature_range());
			test_features(features);*/

			//std::cout << util::make_type(dataset.get_attribute_data(0)).name() << std::endl;
			//normalize(dataset.get_attribute_data(0));

		//	dataset.get_attribute_data(1);*/
			//dataset.get_feature_range(1);

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}

	/*void test_sequence() {

		try {

			util::dataset<default_attribute_type, util::variant_storage> d(list_of(counting_range(3, 7))(counting_range(4, 8)));

			//dataset_type dataset(util::make_coupling_loader(counting_range(1.0, 5.0), counting_range(2.0, 6.0), point_2_maker<kernel_type>()), list_of(counting_range(3, 7))(counting_range(4, 8)));
			//test_features(dataset.get_feature_range());
			//dataset.get_attribute_data(1);
			//dataset.get_feature_range<int32_t>(1);

		} catch(std::exception &e) { CPPUNIT_FAIL( e.what() ); }
	}*/

};

CPPUNIT_TEST_SUITE_REGISTRATION( geometry_iterator_tester );

