/**
 * Util Native Library
 *
 * Copyright (C) 2014 IRSTEA
 *
 * Auteur/Author:
 *     Jean-luc Lablée - http://itap.irstea.fr/?page_id=2277
 *
 * =========================================================================
 *
 * Ce logiciel est régi par la licence CeCILL-C soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL-C telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL-C, et que vous en avez accepté les
 * termes.
 *
 * =========================================================================
 *
 * This software is governed by the CeCILL-C license under French law and
 * abiding by the rules of distribution of free software.  You can  use,
 * modify and/ or redistribute the software under the terms of the CeCILL-C
 * license as circulated by CEA, CNRS and INRIA at the following URL
 * "http://www.cecill.info".
 *
 * As a counterpart to the access to the source code and  rights to copy,
 * modify and redistribute granted by the license, users are provided only
 * with a limited warranty  and the software's author,  the holder of the
 * economic rights,  and the successive licensors  have only  limited liability.
 *
 * In this respect, the user's attention is drawn to the risks associated
 * with loading,  using,  modifying and/or developing or reproducing the
 * software by the user in light of its specific status of free software,
 * that may mean  that it is complicated to manipulate,  and  that  also
 * therefore means  that it is reserved for developers  and  experienced
 * professionals having in-depth computer knowledge. Users are therefore
 * encouraged to load and test the software's suitability as regards their
 * requirements in conditions enabling the security of their systems and/or
 * data to be ensured and,  more generally, to use and operate it in the
 * same conditions as regards security.
 *
 * The fact that you are presently reading this means that you have had
 * knowledge of the CeCILL-C license and that you accept its terms.
 */
 #ifndef ANY_LOADER_HPP_
#define ANY_LOADER_HPP_

#include <pstade/oven/any_range.hpp>
#include <boost/scoped_ptr.hpp>
#include <boost/serialization/serialization.hpp>
#include <boost/serialization/nvp.hpp>
#include <boost/serialization/scoped_ptr.hpp>
#include <util/utility.hpp>
#include <util/data/loader_data_getter.hpp>

namespace util {

template <class T> struct any_loader_traits {

	typedef pstade::oven::any_range<T, boost::forward_traversal_tag> iterator_range;
};

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

namespace detail {

template <class T> class abstract_loader : public boost::noncopyable {

	friend class boost::serialization::access;

public:
	typedef typename any_loader_traits<T>::iterator_range iterator_range;

	virtual iterator_range range() const = 0;
	virtual abstract_loader *clone() const = 0;

	friend bool operator== (const abstract_loader &lhs, const abstract_loader &rhs) { return lhs.is_equal(rhs); }

private:
	virtual bool is_equal(const abstract_loader &other) const = 0;

	template<class Archive> void serialize(Archive &ar, const unsigned int version) {}
};

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

template <class Loader, class T = typename boost::range_value<typename loader_data_traits<Loader>::type>::type> class concrete_loader : public abstract_loader<T> {

	friend class boost::serialization::access;

	typedef abstract_loader<T> base_type;

public:
	typedef typename base_type::iterator_range iterator_range;

	concrete_loader(const Loader &loader) : loader(loader) {}

	iterator_range range() const { return pstade::oven::make_any_range(get_data(loader)); }

private:
	Loader loader;

	concrete_loader() : base_type() {} // for serialization purpose only

	base_type *clone() const { return new concrete_loader<Loader>(loader); }

	bool is_equal(const base_type &other) const { return loader == static_cast<const concrete_loader &>(other).loader; }

	template<class Archive> void serialize(Archive &ar, const unsigned int version) {
		ar & BOOST_SERIALIZATION_BASE_OBJECT_NVP(base_type);
		ar & BOOST_SERIALIZATION_NVP(loader);
	}
};

} // namespace detail

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

template <class T> class any_loader : public util::nonassignable {

	friend class boost::serialization::access;

public:
	typedef typename any_loader_traits<T>::iterator_range iterator_range;

	any_loader() {} // for serialization purpose only
	template <class Loader> any_loader(const Loader &loader) : loader(new detail::concrete_loader<Loader>(loader)) {}
	any_loader(const any_loader &other) : loader(other.loader->clone()) {}

	iterator_range range() const { return loader->range(); }

	friend bool operator== (const any_loader &lhs, const any_loader &rhs) { return *lhs.loader == *rhs.loader; }

private:
	boost::scoped_ptr<detail::abstract_loader<T> > loader;

	template<class Archive> void serialize(Archive &ar, const unsigned int version) {
		ar & BOOST_SERIALIZATION_NVP(loader);
	}
};

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

template <class T> struct loader_data_traits<any_loader<T> > {

	typedef typename any_loader<T>::iterator_range type;
};

template <class T> typename any_loader<T>::iterator_range get_data(const any_loader<T> &loader) {
	return loader.range();
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

template <class Loader> any_loader<typename boost::range_value<typename loader_data_traits<Loader>::type>::type> make_any_loader(const Loader &loader) {
	return any_loader<typename boost::range_value<typename loader_data_traits<Loader>::type>::type>(loader);
}

} // namespace util

#endif /* ANY_LOADER_HPP_ */
